from fps import Module

from jupyverse_api.auth import Auth

from .backends import _NoAuth


class NoAuthModule(Module):
    async def prepare(self) -> None:
        no_auth = _NoAuth()
        self.put(no_auth, Auth)



from __future__ import annotations

from typing import Any

from fastapi import WebSocket

from jupyverse_api.auth import Auth, User

USER = User()


class _NoAuth(Auth):
    def current_user(self, *args, **kwargs):
        async def _():
            return USER

        return _

    def websocket_auth(self, permissions: dict[str, list[str]] | None = None):
        async def _(
            websocket: WebSocket,
        ) -> tuple[WebSocket, dict[str, list[str]] | None] | None:
            return websocket, permissions

        return _

    async def update_user(self):
        async def _(data: dict[str, Any]) -> User:
            global USER
            user = dict(USER)
            user.update(data)
            USER = User(**user)
            return USER

        return _
